@@ -1,10 +1,6 @@
 import copy
 import json
-
-from loguru import logger
-
 from traspider import Engine
-
 from traspider.core.request import Request
 from traspider.core.response import Response
 from traspider.util.exception import WrongParameter
@@ -13,9 +9,16 @@ from traspider.util.node_vm.node import Node
 
 
 class Spider:
-	def __init__(self):
-		self.urls = []
 
+	def __init__(self):
+		self.__save_type = None
+		self.__task_num = None
+		self.__node = None
+		self.__mysql_setting = None
+		self.__save_path = None
+		self.__paging = None
+		self.__urls = None
+		self.__retry = None
 
 	def start_request(self):
 		for url in self.urls:
@@ -82,6 +85,20 @@ class Spider:
 			raise ValueError('<The retry attribute must be an integer and greater than 0>')
 		self.__retry = value
 
+	@property
+	def urls(self):
+		if hasattr(self, "_Spider__urls"):
+			return self.__urls
+		return []
+
+	@urls.setter
+	def urls(self,val):
+		if not val is None:
+			self.__urls = val
+		else:
+			self.__urls = []
+
+
 	@property
 	def paging(self):
 		if hasattr(self, "_Spider__paging"):
@@ -192,7 +209,7 @@ class Spider:
 	def time_out(self):
 		if hasattr(self, "_Spider__time_out"):
 			return self.__time_out
-		return 5
+		return 10
 
 	@time_out.setter
 	def time_out(self, value):
